package com.tencent.txcplayeradapterdemo;

import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.widget.EditText;
import android.widget.Toast;

import com.tencent.txcplayeradapter.ITXCPlayerAssistor;
import com.tencent.txcplayeradapter.ITXCRequestVideoInfoCallback;
import com.tencent.txcplayeradapter.TXCPlayerAdapter;
import com.tencent.txcplayeradapter.model.TXCImageSpriteInfo;
import com.tencent.txcplayeradapter.model.TXCKeyFrameDescInfo;
import com.tencent.txcplayeradapter.model.TXCStreamingInfo;
import com.tencent.txcplayeradapter.model.TXCVideoBasicInfo;

import java.util.List;

import androidx.appcompat.app.AppCompatActivity;

public class MainActivity extends AppCompatActivity implements View.OnClickListener {

    private final String TAG = "MainActivity";

    // pcfg=basicDrmPreset
    private String DEFAULT_PSIGN = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhcHBJZCI6MTI1NDQzMjAzOSwiZmlsZUlkIjoiNTI4NTg5MDgxNTU3NjI5Mzc1MiIsImN1cnJlbnRUaW1lU3RhbXAiOjE2MTYwMzQ2NDAsImV4cGlyZVRpbWVTdGFtcCI6MTY0MDAzNDY0MCwicGNmZyI6ImJhc2ljRHJtUHJlc2V0IiwidXJsQWNjZXNzSW5mbyI6e30sImRybUxpY2Vuc2VJbmZvIjp7ImV4cGlyZVRpbWVTdGFtcCI6MTY0MDAzNDY0MH19.wI7ETGZ04piZZqtTkxuGgZukrILMuAIfIS9eJgEYP6Q";

    // pcfg=Default
//    private String DEFAULT_PSIGN2 = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9" +
//            ".eyJhcHBJZCI6MTI1NDQzMjAzOSwiZmlsZUlkIjoiNTI4NTg5MDgxNTU3NjI5Mzc1MiIsImN1cnJlbnRUaW1lU3RhbXAiOjE2MTU5NDkwMzMsInVybEFjY2Vzc0luZm8iOnt9LCJkcm1MaWNlbnNlSW5mbyI6e319.rLzjw4L8BMUTTLrm6VRkD63e9sB9g0QxvqIz6goTZjg";

    private ITXCPlayerAssistor mPlayerAssistor;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        initView();
    }

    private void initView() {
        findViewById(R.id.btn_play).setOnClickListener(this);
    }

    @Override
    public void onClick(View v) {
        String appId = ((EditText) findViewById(R.id.ed_appid)).getText().toString();
        String fileId = ((EditText) findViewById(R.id.ed_fileid)).getText().toString();
        String pSign = ((EditText) findViewById(R.id.ed_psign)).getText().toString();
        if (TextUtils.isEmpty(appId) || TextUtils.isEmpty(fileId) || TextUtils.isEmpty(pSign)) {
            Toast.makeText(this, "appId, fileId, pSign 不能为空", Toast.LENGTH_SHORT).show();
            return;
        }
        startPlay(appId, fileId, pSign);
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        // 销毁
        TXCPlayerAdapter.destroy();
    }

    private void startPlay(String appId, String fileId, String pSign) {
        TXCPlayerAdapter.init(Integer.valueOf(appId));
        TXCPlayerAdapter.setLogEnable(true);

        if(mPlayerAssistor != null){
            TXCPlayerAdapter.destroyPlayerAssistor(mPlayerAssistor);
        }

        mPlayerAssistor = TXCPlayerAdapter.createPlayerAssistor(fileId, pSign);
        mPlayerAssistor.requestVideoInfo(new ITXCRequestVideoInfoCallback() {

            @Override
            public void onError(int errCode, String msg) {
                Log.d(TAG, "onError msg = " + msg);
            }

            @Override
            public void onSuccess() {
                Log.d(TAG, "onSuccess");

                List<TXCKeyFrameDescInfo> keyFrameDescInfos = mPlayerAssistor.getKeyFrameDescInfo();
                Log.d(TAG, "keyFrameDescInfos = " + keyFrameDescInfos);

                TXCStreamingInfo streamingInfo = mPlayerAssistor.getStreamingInfo();
                Log.d(TAG, "streamingInfo = " + streamingInfo);

                TXCVideoBasicInfo videoBasicInfo = mPlayerAssistor.getVideoBasicInfo();
                Log.d(TAG, "videoBasicInfo = " + videoBasicInfo);

                TXCImageSpriteInfo imageSpriteInfo = mPlayerAssistor.getImageSpriteInfo();
                Log.d(TAG, "imageSpriteInfo = " + imageSpriteInfo);

                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        if (mPlayerAssistor.getStreamingInfo() != null) {
                            VideoActivity.playVideo(MainActivity.this, mPlayerAssistor.getStreamingInfo().playUrl);
                        } else {
                            Toast.makeText(MainActivity.this, "streamInfo = null", Toast.LENGTH_SHORT).show();
                        }
                    }
                });
            }
        });
    }
}